@@ -1,6 +1,6 @@
 from junit_xml import TestSuite, TestCase
-from termcolor import cprint
 
+from neoload_cli_lib.tools import print_color
 from neoload_cli_lib import tools
 
 __SLA_global = 'Global'
@@ -17,16 +17,16 @@ def print_result_summary(json_result, sla_json_global, sla_json_test, sla_json_i
 
 
 def __print_sla(sla_json_global, sla_json_test, sla_json_interval):
-    cprint("SLA summary:")
+    print_color("SLA summary:")
     for sla in sla_json_global:
         __print_one_sla(__SLA_global.replace(' ', ''), sla)
-    cprint('')
+    print_color('')
     for sla in sla_json_test:
         __print_one_sla(__SLA_test.replace(' ', ''), sla)
-    cprint('')
+    print_color('')
     for sla in sla_json_interval:
         __print_one_sla(__SLA_interval.replace(' ', ''), sla)
-    cprint('')
+    print_color('')
 
 
 def __print_one_sla(kind, sla_json):
@@ -44,13 +44,11 @@ def __print_one_sla(kind, sla_json):
 
     if kind == __SLA_interval.replace(' ', ''):
         if status == "WARNING":
-            threshold = sla_json['warningThreshold']
-            where = ' [%.3f%% %s %s]' % (sla_json['warning'], threshold['operator'], threshold['value'])
+            where = ' [%.3f%% %s]' % (sla_json['warning'], build_threshold_str(sla_json['warningThreshold']))
         elif status == "FAILED":
-            threshold = sla_json['failedThreshold']
-            where = ' [%.3f%% %s %s]' % (sla_json['failed'], threshold['operator'], threshold['value'])
+            where = ' [%.3f%% %s]' % (sla_json['failed'], build_threshold_str(sla_json['failedThreshold']))
 
-    return cprint("%sSLA [%s] %s on [%s%s]" % (kind, sla_json['kpi'], status, element, where), color)
+    return print_color("%sSLA [%s] %s on [%s%s]" % (kind, sla_json['kpi'], status, element, where), color)
 
 
 def __get_color_from_status(status: str):
@@ -60,8 +58,10 @@ def __get_color_from_status(status: str):
     }.get(status, "red")
 
 
-def print_result_junit(json_result, sla_json_test, sla_json_interval, junit_file_path):
+def print_result_junit(json_result, sla_json_test, sla_json_interval, sla_json_global, junit_file_path):
     junit_suites = []
+    for sla in sla_json_global:
+        junit_suites.append(__build_test_suite(json_result, __SLA_global, sla))
     for sla in sla_json_test:
         junit_suites.append(__build_test_suite(json_result, __SLA_test, sla))
     for sla in sla_json_interval:
@@ -73,10 +73,15 @@ def print_result_junit(json_result, sla_json_test, sla_json_interval, junit_file
 
 def __build_test_suite(json_result, kind, sla_json):
     status = sla_json['status']
-    category = sla_json['element']['category']
-    user_path = sla_json['element']['userpath']
-    suite_name = 'com.neotys.%s.%s%s' % (
-        category, kind.replace(' ', ''), ('' if user_path == '' else '.%s' % user_path))
+
+    if 'element' in sla_json.keys():
+        category = sla_json['element']['category']
+        user_path = sla_json['element']['userpath']
+        suite_name = 'com.neotys.%s.%s%s' % (
+            category, kind.replace(' ', ''), ('' if user_path == '' else '.%s' % user_path))
+    else:
+        suite_name = 'com.neotys.%s' % (kind.replace(' ', ''))
+
     test_name = sla_json['kpi']
 
     tc = TestCase(test_name, suite_name)
@@ -87,40 +92,48 @@ def __build_test_suite(json_result, kind, sla_json):
     return TestSuite(suite_name, [tc])
 
 
+def build_threshold_str(threshold):
+    operation = threshold['operator']
+    value = threshold.get('value') or threshold.get('values') or ''
+    return f'between {value[0]} and {value[1]}' if operation == 'btw' else f'{operation} {value}'
+
+
 def __build_unit_test(json_result, kind, sla_json):
     status = sla_json['status']
-    element = sla_json['element']
+
     reported = 0
-    if kind == __SLA_test:
+
+    if kind == __SLA_test or kind == __SLA_global:
         reported = sla_json['value']
     elif status == "FAILED":
         reported = sla_json['failed']
     elif status == "WARNING":
         reported = sla_json['warning']
 
-    operation = ''
-    value = ''
-    if kind == __SLA_interval:
-        if status == "FAILED":
-            threshold = sla_json['failedThreshold']
-            operation = threshold['operator']
-            value = threshold['value']
-        if status == "WARNING":
-            threshold = sla_json['warningThreshold']
-            operation = threshold['operator']
-            value = threshold['value']
+    threshold_str = ''
+
+    if status == "FAILED":
+        threshold_str = build_threshold_str(sla_json['failedThreshold'])
+    if status == "WARNING":
+        threshold_str = build_threshold_str(sla_json['warningThreshold'])
+
+    text = ''
+
+    if 'element' in sla_json.keys():
+        element = sla_json['element']
+        text += 'Container: %s<br/>' % element['name']
+        text += 'Path: User Paths > %s > Init > %s > %s<br/>' % (element['userpath'], element['parent'], element['name'])
+        text += 'Virtual User: %s<br/>' % element['userpath']
+        text += 'SLA Profile: %s<br/>' % element['category']
 
-    text = 'Container: %s<br/>' % element['name']
-    text += 'Path: User Paths > %s > Init > %s > %s<br/>' % (element['userpath'], element['parent'], element['name'])
-    text += 'Virtual User: %s<br/>' % element['userpath']
-    text += 'SLA Profile: %s<br/>' % element['category']
     text += 'SLA Type: %s<br/>' % kind
     text += '%s Type: %s<br/>' % (status, sla_json['kpi'])
     text += 'Project: %s<br/>' % json_result['project']
     text += 'Scenario: %s<br/>' % json_result['scenario']
     text += '<br/>'
-    text += '%s<br/>description: if the %s %s %s then fail<br/><br/>' % (status, sla_json['kpi'], operation, value)
+    text += '%s<br/>description: if the %s %s then fail<br/><br/>' % (status, sla_json['kpi'], threshold_str)
     text += 'Results: <br/><br/>'
     text += '%s=%s%%<br/><br/>' % (sla_json['kpi'], str(reported))
     text += 'Created N/A<br/>'
+
     return text
